MulVectorMatrix

Trait MulVectorMatrix 

pub trait MulVectorMatrix<Matrix> {
    type VectorType;

    // Required methods
    fn mul_matrix_left(&self, lhs: &Matrix) -> Self::VectorType;
    fn mul_matrix(&self, rhs: &Matrix) -> Self::VectorType;
}
Adds matrix operations to vector types.

Required Associated Types

Required Methods

fn mul_matrix_left(&self, lhs: &Matrix) -> Self::VectorType

Interprets self as a column vector and multiplies the given matrix from the left-hand-side, i.e. lhs * self

fn mul_matrix(&self, rhs: &Matrix) -> Self::VectorType

Interprets self as a row vector and multiplies the given matrix from the right-hand-side, i.e. self * rhs

Implementors

Source

impl MulVectorMatrix<[f32; 9]> for Vec3

Available on crate feature Matrix3 only.
Source

impl MulVectorMatrix<[f32; 16]> for Vec3

Available on crate feature Matrix4 only.
Source

impl MulVectorMatrix<[f32; 16]> for Vec4

Available on crate feature Matrix4 only.